@@ -4,7 +4,7 @@
 #' \href{https://github.com/neurogenomics/rworkflows}{rworkflows}
 #' \href{https://github.com/features/actions}{GitHub Actions (GHA)}  
 #' @param template Workflow template name.
-#' \itemize{
+#' \describe{
 #' \item{"rworkflows"}{A short workflow script that calls
 #'  the GitHub action from the GitHub Marketplace.
 #' The action is continually updated 
@@ -13,6 +13,9 @@
 #' explicitly copies all steps from the \pkg{rworkflows} action
 #' into a static file. Users may need to update this file themselves over time,
 #' though this does allow for a fully customisable workflow.}
+#' Optionally, you can include the suffix ":<branch>" to specify which branch 
+#' you would like to download the "action.yml" file from to create the 
+#' static workflow template.
 #' }
 #' @param name An arbitrary name to call the workflow.
 #' @param tag Which version of the \code{rworkflows} action to use. 
@@ -41,7 +44,6 @@
 #' @param run_pkgdown Knit the \emph{README.Rmd} (if available), 
 #' build documentation website, and deploy to \emph{gh-pages} branch.
 #' @param has_runit Run R Unit tests.
-#' @param run_docker Whether to build and push a Docker container to DockerHub.
 #' @param has_latex Install a suite of LaTeX dependencies used for 
 #' rendering Sweave (.rnw) and other documentation files.
 #' @param tinytex_installer  Which release of tinytex (bundles of LaTeX
@@ -66,13 +68,24 @@
 #' Read 
 #' \href{https://docs.github.com/en/actions/security-guides/automatic-token-authentication}{
 #' here for more details}.
-#' @param docker_user DockerHub username.
-#' @param docker_org DockerHub organization name. 
+#' @param run_docker Whether to build and push a Docker container to DockerHub.
+#' @param docker_registry Docker container registry to push to. 
+#' Options include:
+#' \describe{
+#'  \item{"ghcr.io" : }{\href{https://docs.github.com/en/packages/working-with-a-github-packages-registry/working-with-the-container-registry}{
+#'  GitHub Container Registry}}  
+#'  \item{"docker.io" : }{\href{https://hub.docker.com/}{DockerHub}}
+#' }
+#' @param docker_user Docker registry username.
+#' Not used when \code{docker_registry="ghcr.io"}.
+#' @param docker_org Docker registry organization name. 
 #' Is the same as \code{docker_user} by default.
-#' @param docker_token DockerHub token.
+#' Not used when \code{docker_registry="ghcr.io"}.
+#' @param docker_token Docker registry token.
+#' Not used when \code{docker_registry="ghcr.io"}.
+#' 
 #' @param force_new If the GHA workflow yaml already exists, 
 #' overwrite with new one (default: \code{FALSE}).
-#' 
 #' @param save_dir Directory to save workflow to.
 #' @param return_path Return the path to the saved \emph{yaml} workflow file
 #' (default: \code{TRUE}), or return the \emph{yaml} object directly.
@@ -82,6 +95,41 @@
 #' @param enable_act Whether to add extra lines to the yaml to 
 #' enable local workflow checking with 
 #' \href{https://github.com/nektos/act}{act}.
+#' @param miniforge_variant If provided, this variant of Miniforge will be
+#'  downloaded and installed. If \code{miniforge_variant=false}, 
+#'  Miniforge will not be installed at all.
+#'  If \code{miniforge_variant=""}, the "Miniforge3" variant will be installed.
+#'  If \code{miniforge_version} is not provided, the \code{latest} 
+#'  version will be used.
+#'  Currently-known values: - "Miniforge3" (default) - "Miniforge-pypy3" -
+#'  "Mambaforge" - "Mambaforge-pypy3".
+#'  Visit
+#'  https://github.com/conda-forge/miniforge/releases/ for more information on
+#'  available variants.
+#' @param miniforge_version If provided, this version of the given Miniforge
+#'  variant will be downloaded and installed. If \code{miniforge_variant} is 
+#'  not provided, "Miniforge3" will be used. Visit
+#'  https://github.com/conda-forge/miniforge/releases/ for more information on
+#'  available versions.
+#' @param activate_environment Environment name (or path) to activate on all 
+#' shells. Default is "test" which will be created in \emph{$CONDA/envs/test}. 
+#' If an empty string is used, no environment is activated by default 
+#' (For "base" activation see the \code{auto-activate-base} option). 
+#' If the environment does not exist, it will
+#' be created and activated. If \code{environment-file} is used and you want 
+#' that to be the environment used, you need to explicitly provide the name of
+#' that environment on \code{activate-environment}. 
+#' If using \code{sh/bash/cmd.exe}
+#' shells please read the IMPORTANT! section on the README.md! to properly
+#' activate conda environments on these shells.
+#' @param environment_file Path or URL to a .yml file to build the 
+#' conda environment with. For more information see
+#' \href{https://docs.conda.io/projects/conda/en/latest/user-guide/tasks/manage-environments.html#creating-an-environment-from-an-environment-yml-file}{
+#' here}.
+#' @param channels  Conda configuration. Comma separated list of channels 
+#' to use in order of priority. See
+#' \href{https://docs.conda.io/projects/conda/en/latest/user-guide/configuration/}{here}
+#' for more information.
 #' @param preview Print the yaml file to the R console.
 #' @param verbose Print messages.
 #' @returns Path or yaml object.
@@ -104,25 +152,37 @@ use_workflow <- function(## action-level args
                          branches=c("master","main","devel","RELEASE_**"),
                          runners=construct_runners(),
                          ## workflow-level args
+                         ### General
+                         github_token="${{ secrets.GITHUB_TOKEN }}",
+                         cache_version="cache-v1",
+                         enable_act=FALSE,
+                         ### Checks
                          run_bioccheck=FALSE,
                          run_rcmdcheck=TRUE, 
                          as_cran=TRUE,
                          run_vignettes=TRUE,
                          has_testthat=TRUE, 
+                         has_runit=FALSE,
                          run_covr=TRUE, 
-                         run_pkgdown=TRUE, 
-                         has_runit=FALSE, 
+                         ### Latex
                          has_latex=FALSE,
                          tinytex_installer='TinyTeX-1',
-                         tinytex_version='',
+                         tinytex_version=NULL, 
                          pandoc_version='2.19',
+                         ### Site 
+                         run_pkgdown=TRUE,   
+                         ### Container
                          run_docker=FALSE,  
-                         github_token="${{ secrets.GITHUB_TOKEN }}",
+                         docker_registry="ghcr.io",
                          docker_user=NULL,
                          docker_org=docker_user,
                          docker_token="${{ secrets.DOCKER_TOKEN }}",
-                         cache_version="cache-v1",
-                         enable_act=FALSE,
+                         ### Miniconda
+                         miniforge_variant=FALSE,
+                         miniforge_version=NULL,
+                         activate_environment="test",
+                         environment_file=NULL,
+                         channels=NULL,
                          ## function-level args
                          save_dir=here::here(".github","workflows"),
                          return_path=TRUE,
@@ -132,9 +192,23 @@ use_workflow <- function(## action-level args
   
   # devoptera::args2vars(use_workflow);  docker_org <- eval(docker_org)   
 
+  #### Extract branch name from template arg ####
+  if(grepl(":",template)){
+    action_branch <- gsub(".*:","",template)
+    template <- gsub(":.*","",template)
+    name <- gsub("[:]","_",name)
+  } else {
+    action_branch <- "master"
+  }
+  #### Construct yaml path ####
+  path <-if(is.null(save_dir)){
+    NULL
+  } else {
+    file.path(save_dir,paste0(name,".yml"))
+  }
   #### Check for existing yaml ####
-  path <- file.path(save_dir,paste0(name,".yml"))
-  if(file.exists(path) &&
+  if(!is.null(path) && 
+     file.exists(path) &&
      isFALSE(force_new)){
     messager("Using existing workflow file:",path,v=verbose) 
     yml <- yaml::read_yaml(path)
@@ -150,7 +224,8 @@ use_workflow <- function(## action-level args
     }
   }
   #### Read yaml template ####
-  yml <- get_yaml(template = template)
+  yml <- get_yaml(template = template, 
+                  action_branch = action_branch)
   #### Fill yaml template ####
   yml <- fill_yaml(yml=yml,
                    ## action-level args
@@ -161,6 +236,7 @@ use_workflow <- function(## action-level args
                    branches=branches,
                    runners=runners,
                    ## workflow-level args
+                   github_token=github_token,
                    run_bioccheck=run_bioccheck,
                    run_rcmdcheck=run_rcmdcheck, 
                    as_cran=as_cran,
@@ -174,29 +250,28 @@ use_workflow <- function(## action-level args
                    tinytex_version=tinytex_version,
                    pandoc_version=pandoc_version,
                    run_docker=run_docker,  
-                   github_token=github_token,
+                   docker_registry=docker_registry,
                    docker_user=docker_user,
                    docker_org=docker_org,
                    docker_token=docker_token,
+                   miniforge_variant=miniforge_variant,
+                   miniforge_version=miniforge_version,
+                   activate_environment=activate_environment,
+                   environment_file=environment_file,
+                   channels=channels,
                    cache_version=cache_version,
                    enable_act=enable_act)
   #### Preview ####
   if(isTRUE(preview)){
-    cat(yaml::as.yaml(yml)) 
-  }
-  #### Write to disk ####
-  if(!is.null(save_dir)){  
-    save_yaml(yml=yml,
-              path=path,
-              verbose=verbose)
-    #### Return ####
-    if(isTRUE(return_path)){
-      return(path)
-    } else {
-      yml <- yaml::read_yaml(path)
-      return(yml)
-    }
-  } else {
-    return(yml)
+    preview_yaml(yml=yml) 
   }
+  #### Save yaml #### 
+  handlers <- list('bool#yes' = function(x){"${{ true }}"},
+                   'bool#no' = function(x){"${{ false }}"})
+  path_or_yaml <- return_yaml(yml=yml,
+                              path=path,
+                              return_path=return_path,
+                              handlers=handlers,
+                              verbose=verbose)
+  return(path_or_yaml)
 }
