@@ -1,4 +1,9 @@
 test_that("check_cont works", {
+  ## Don't run on CRAN servers due to ongoing internet connectivity issues
+  if(!is_gha()) {
+    testthat::skip_if_offline()
+    testthat::skip_on_cran()
+  }
   
   testthat::expect_no_warning(
     check_cont(cont = "bioconductor/bioconductor_docker:devel")
